package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcTbcz;

/**
 * 通报处置Service接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface ITcTbczService 
{
    /**
     * 查询通报处置
     * 
     * @param id 通报处置主键
     * @return 通报处置
     */
    public TcTbcz selectTcTbczById(Long id);

    /**
     * 查询通报处置列表
     * 
     * @param tcTbcz 通报处置
     * @return 通报处置集合
     */
    public List<TcTbcz> selectTcTbczList(TcTbcz tcTbcz);

    /**
     * 新增通报处置
     * 
     * @param tcTbcz 通报处置
     * @return 结果
     */
    public int insertTcTbcz(TcTbcz tcTbcz);

    /**
     * 修改通报处置
     * 
     * @param tcTbcz 通报处置
     * @return 结果
     */
    public int updateTcTbcz(TcTbcz tcTbcz);

    /**
     * 批量删除通报处置
     * 
     * @param ids 需要删除的通报处置主键集合
     * @return 结果
     */
    public int deleteTcTbczByIds(Long[] ids);

    /**
     * 删除通报处置信息
     * 
     * @param id 通报处置主键
     * @return 结果
     */
    public int deleteTcTbczById(Long id);

    /**
     * 导入通报处置信息
     *
     * @return 结果
     */
    public String importUser(List<TcTbcz> tcTbczList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
