package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcSslx;
import com.ruoyi.tcZz.domain.TcTbcz;
import com.ruoyi.tcZz.service.ITcTbczService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 通报处置Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "通报处置")
@RequestMapping("/tcZz/networkSecurity/tbcz")
public class TcTbczController extends BaseController {
    @Autowired
    private ITcTbczService tcTbczService;

    /**
     * 查询通报处置列表
     */
    @ApiOperation(value = "查询通报处置列表", response = TcTbcz.class)
    @GetMapping("/list")
    public TableDataInfo list(TcTbcz tcTbcz) {
        startPage();
        List<TcTbcz> list = tcTbczService.selectTcTbczList(tcTbcz);
        return getDataTable(list);
    }

    /**
     * 导出通报处置列表
     */
    @ApiOperation(value = "导出通报处置列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcTbcz tcTbcz) {
        List<TcTbcz> list = tcTbczService.selectTcTbczList(tcTbcz);
        ExcelUtil<TcTbcz> util = new ExcelUtil<TcTbcz>(TcTbcz.class);
        util.exportExcel(response, list, "通报处置数据");
    }

    /**
     * 获取通报处置详细信息
     */
    @ApiOperation(value = "获取通报处置详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcTbczService.selectTcTbczById(id));
    }

    /**
     * 新增通报处置
     */
    @ApiOperation(value = "新增通报处置")
    @PostMapping
    public AjaxResult add(@RequestBody TcTbcz tcTbcz) {
        return toAjax(tcTbczService.insertTcTbcz(tcTbcz));
    }

    /**
     * 修改通报处置
     */
    @ApiOperation(value = "修改通报处置")
    @PutMapping
    public AjaxResult edit(@RequestBody TcTbcz tcTbcz) {
        return toAjax(tcTbczService.updateTcTbcz(tcTbcz));
    }

    /**
     * 删除通报处置
     */
    @ApiOperation(value = "删除通报处置")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcTbczService.deleteTcTbczByIds(ids));
    }



    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcTbcz> util = new ExcelUtil<TcTbcz>(TcTbcz.class);
        List<TcTbcz> tcTbczList = util.importExcel(file.getInputStream());
        tcTbczService.importUser(tcTbczList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcTbczService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcTbcz> util = new ExcelUtil<TcTbcz>(TcTbcz.class);
        util.importTemplateExcel(response, " 通报处置");
    }
}
